@@ -14,4 +14,14 @@ sub show_pet_by_id_get {
   $self->list_pets_get(@_);
 }
 
+sub add_pet_post {
+  my $self = shift;
+  $RES->{body} = $self->req->body;
+  $self->list_pets_get(@_);
+}
+
+sub update_pet_put {
+  shift->list_pets_get(@_);
+}
+
 1;
